Overview
========

Extensions for logbook, such as Windows EventLog handler.

Checking out the code
=====================
To run this code from the repository for development purposes, run the following:

    easy_install -U infi.projector
    projector devenv build

Python 3
========

Support for Python 3 is experimental at this stage
